function acpnuage(CP,cpa,cpb,Xcol,indnames,K,xoomK)
%
% ACPNUAGE :          Nuage des individus d'une ACP sur le plan de
%    2 composantes d'indices cpa et cpb. Les points du nuage peuvent
%    etre associs  une chelle de couleurs selon un vecteur donn. 
%    Les marqueurs des points peuvent etre 2 triangles proportionns 
%    par les composantes d'une matrice  2 colonnes (K) et d'un 
%    facteur de taille (xoomK). Ces triangles sont orients selon 
%    l'abscisse et l'ordonne de la faon suivante :
%    - avec Matlab : vers la droite pour l'abscisse et vers le haut 
%                    pour l'ordonne
%    - avec Octave3.2.4 : vers le haut pour l'abscisse et vers le
%                    bas pour l'ordonne.
%
% acpnuage(CP,cpa,cpb,Xcol,indnames,K,xoomK);
%
% Entres :
% ---------
% CP       : Matrice des composantes principales de l'ACP.
% cpa, cpb : Indices des 2 composantes principales (en colonne)  prendre
%            en compte pour former le plan du nuage des individus.
% Xcol     : Vecteur sur lequel sera tablie l'chelle de couleur
%            des points. Si Xcol est vide (==[]), les points seront
%            tous de la meme couleur (bleu).
% indnames : Tableaux des noms des individus (points) avec lesquels
%            ils pourront etre labliss si le tableau n'est pas vide ([]).
%            Dans ce cas, il doit avoir la meme longueur que CP.
% K        : Matrice de la meme taille que CP (par exemple une matrice
%            des contributions, ou des qualits de reprsentation) dont 
%            les colonnes d'indices cpa et cpb seront utilises pour proportionner
%            les marqueurs triangles selon l'abscisse et l'ordonnes.
%            K doit avoir les memes dimensions que CP
% xoomK    : facteur de grossissement pour les marqueurs en formes de triangles
%             dterminer exprimentalement de faon convenable.
%
% Remarque : Pour avoir un point de comparaison, lorsque les marqueurs triangles 
%----------- sont utiliss, nous avons reprsent, en bas et  gauche de la figure, 
%            3 triangles noirs dont les tailles correspondent respectivement  des
%            facteurs de 1.0 , 0.5 et 0.1 du facteur xoomK indiqu. 

%_________________________________________________________
% Auteur : C.Sorror 2012 Modifi en 2014
% --------------------------------------------------------
% some checks
if (nargin>=6)
   if (size(CP)~=size(K))
      error('acpnuage error : CP and K must be the same size');
   end
end
if (nargin<=4) indnames=[]; end
if (~isempty(indnames))
   if (length(indnames)~=size(CP,1))
      error('acpnuage error : when indnames is given it must be the same size as CP');
   end
end
if (nargin<=3) Xcol=[]; end
% Sized scatter plot
if (nargin==6) xoomK = 1; end % K default zoom size
%
% --------------------------------------------------------
figure; hold on

if (~isempty(Xcol))
   % Dfinition d'une map de couleur ncessaire dans le cas du plot qui va suivre
   Colmap  = jet(64);
   % Normalise le vecteur Xcol dans l'intervalle [a=1 b=64]
   mincol=min(Xcol); maxcol=max(Xcol); dcol=maxcol-mincol; dr=64-1;
   ICol = 1 + dr * (Xcol - mincol) / dcol; %dans [a b]
   ICol = round(ICol);
end

if (exist('OCTAVE_VERSION'))   
   omark = '<'; % ordonne marqueur OCTAVE VERSION 
else
   omark = '^'; % ordonne marqueur MATLAB VERSION 
end   
% --------------------------------------------------------
if (nargin>=6) % on veut des triangles (proportionns)
      % Pour avoir la bonne chelle de couleur je passe par scatter ... mais ... 
      if (~isempty(Xcol))
         scatter(CP(:,cpa),CP(:,cpb),0.1,Xcol); % pb: Ca ajoute un point (pas trop drangeant)   
      end                                       % meme sans scatter, c'est le plot aprs qui ajoute un point ?
      %                                          
      Z = K(:,[cpa,cpb])*xoomK; % Taille des marqueurs
      [n, p] = size(CP);
      %
      % plot des points : j'ai fais une boucle sur plot car, pour Octave je n'ai
      % pas russi  introduire le facteur taille (markersize) avec scatter
      if (~isempty(Xcol))
         for kk=1:n
            ic = ICol(kk);
            % Abscisse marker
            plot(CP(kk,cpa),CP(kk,cpb),'marker','>','markersize',Z(kk,1),'linewidth',1.3,'color',Colmap(ic,:)); %up
            % Ordonne marker
            plot(CP(kk,cpa),CP(kk,cpb),'marker',omark,'markersize',Z(kk,2),'linewidth',1.3,'color',Colmap(ic,:)); %down
         end
      else
         for kk=1:n
            % Abscisse marker
            plot(CP(kk,cpa),CP(kk,cpb),'marker','>','markersize',Z(kk,1),'linewidth',1.3);  %up
            % Ordonne marker
            plot(CP(kk,cpa),CP(kk,cpb),'marker',omark,'markersize',Z(kk,2),'linewidth',1.3);  %down         
         end        
      end
else % On ne veut pas de triangles proportionns
      % Default basic scatter plot 
      if (~isempty(Xcol)) % (avec une echelle de couleur tout de meme, ...)
         %scatter(CP(:,cpa),CP(:,cpb),5,Xcol);
         h=scatter(CP(:,cpa),CP(:,cpb),5,Xcol);
         if (~exist('OCTAVE_VERSION'))  
             set(h,'linewidth',2); colorbar; 
         end
      else
         %scatter(CP(:,cpa),CP(:,cpb),5); % (... ou pas)(bleu par defaut)
         h=scatter(CP(:,cpa),CP(:,cpb),5); % (... ou pas)(bleu par defaut)
         if (~exist('OCTAVE_VERSION'))  
             set(h,'linewidth',2); 
         end        
      end
end
%
%==========================================================
if (~isempty(Xcol))  %  Si couleur
   if (0) % previous version ( reprendre si problme de colorbar)
      colorbar; 
   else % Une tentative d'adapter spcifiquement la colorbar +|- approprie
      inftick=ceil(mincol);
      suptick=floor(maxcol);
      pastick = 1;
      ntick = suptick-inftick+1;
      while (ntick>12) ntick=ntick/2; pastick=pastick*2; end
      colormap(Colmap);  hc=colorbar; 
      tick=[inftick:pastick:suptick]'; 
      set(hc,'ytick',tick,'yticklabel',tick);
  end
end
%
% Labelisation des points, if not empty
if (~isempty(indnames))
   d = (max(CP(:,cpa)) - min(CP(:,cpa))) / 100;
   for i=1:length(CP(:,cpa))
       %text(CP(i,cpa)+d,CP(i,cpb),indnames(i));
       text(CP(i,cpa)+d,CP(i,cpb),indnames(i),'fontsize',9,'fontweight','bold');
       % fontsize and fontweight may be changed as needed.
   end
end
% les axes du nuages 
axe = axis;
plot([axe(1) axe(2)],[0 0],'k',[0 0],[axe(3) axe(4)],'k');
%
% Plot en noir des triangles de rfrence en bas  gauche
if (nargin>=6) % when marqueur triangle est utilis
   h=get(gca);
   if (exist('OCTAVE_VERSION'))
      dx = (h.xlim(2)-h.xlim(1));
      dy = (h.ylim(2)-h.ylim(1));
      px = h.xlim(1) + (xoomK/512)*dx;
      py = h.ylim(1) + (xoomK/512)*dy*10/9;
   else
      dx = (h.XLim(2)-h.XLim(1));
      dy = (h.YLim(2)-h.YLim(1));
      px = h.XLim(1) + (xoomK/512)*dx;
      py = h.YLim(1) + (xoomK/512)*dy*10/9;
   end
   h=plot(px,py);
   set(h,'marker','>','color','k','MarkerSize',xoomK,'linewidth',1.3);
   h=plot(px,py);
   set(h,'marker','>','color','k','MarkerSize',xoomK*0.5,'linewidth',1.3);
   h=plot(px,py);
   set(h,'marker','>','color','k','MarkerSize',xoomK*0.1,'linewidth',1.3);
end
%
%====================================================
% habillage (peut etre complt et/ou overrid par l'appelant)
xlabel(['axe ', int2str(cpa)],'fontsize',12,'fontweight','demi'); 
ylabel(['axe ', int2str(cpb)],'fontsize',12,'fontweight','demi');
title(sprintf('Nuage des individus sur le plan des axes principaux %i et %i',cpa,cpb));
%
%====================================================
