function [VEPU, CP, VAP] = ocp(X)
%
% OCP     :       ACP (Analyse en Composantes Principales)
%  
% [VEPU, CP, VAP] = ocp(X);
%
% En entree :
% -----------
% X : Matrice des donnes (individus en ligne, variables
%     en colonnes)
% En Sortie :
% -----------
% VEPU : Axes principaux de M-norme 1. Ce sont les vecteurs
%        propres de la matrice de covariance des donnes centres.
% CP   : Composantes principales : coordonnes sur les nouveaux axes
%        de l'ACP.
% VAP  : Valeurs propres des la matrice de covariance des donnes
%        centres.

% ________________________________________________________	
% Auteur : unknown (May be Cecile Mallet)
% modification : novembre 2011 C. Sorror
% --------------------------------------------------------
% Centrer dans tous les cas
XC    = X-(mean(X)'*ones(1,size(X,1)))';
%
[VEPU, VAP] = eig(cov(XC)); 
VAP = diag(VAP);       % vecteur des valeur propres
ACP = [VAP VEPU'];     % associations des valeurs et vecteurs propres
ACP = sortrows(ACP,1); % Classement des lignes selon la premiere colonne par ordre croissant des valeurs propres
ACP = flipud(ACP);     % Classement des lignes selon la premiere colonne par ordre dcroissant des valeurs propres
VAP = ACP(:,1);        % On re spare les valeurs prores, des ...
VEPU = ACP(:,2:end)';  % vecteurs propres qu'on retranspose
%
% In fine, les Composantes Principales
CP   = XC * VEPU;
%
% Problme numrique du zro informatique
Pcent = (VAP/sum(VAP))*100;
Pcent = cumsum(Pcent);
Istop = find(Pcent>=100);
if (length(Istop)>1)
    VAP(Istop(2):end) = 0;
end
%
% --------------------------------------------------------
%