function PcentIg = phinertie(ValPropres)
%
% PHINERTIE :       Calcul et cumuls des pourcentages 
%    d'inertie de valeurs (propres) positives et prsentation
%    graphique par histogramme.
%
% PcentIg = phinertie(ValPropres);
%
% Entres :
% ---------
% ValPropres : Un vecteur de valeurs (propres)
%
% Sorties :
% ---------
% PcentIg % Tableau  2 colonnes dont les lignes sont dans le meme
%           ordre que celles des valeurs :           :
%           - 1re colonne : pourcentage d'inertie
%           - 2me colonne : pourcentage d'inertie cumule

% ________________________________________________________	
% Auteur : unknown 
% modification : 2012 C. Sorror
% --------------------------------------------------------
% On se limite aux VAP > 0
Ipos = find(ValPropres>0);
VAP  = ValPropres(Ipos);
Nvappos = length(Ipos);
%
% Pourcentage et pourcentage cumuls
PcentIg(:,1) = (VAP/sum(VAP))*100;
PcentIg(:,2) = cumsum(PcentIg(:,1));
%
% Affichage des valeurs propres et des inerties
% (en se limitant aux valeurs positives)
fprintf('\nValeurs P.   : ');      fprintf(' %3.2f ', VAP');
fprintf('\n%cInertie     : ','%'); fprintf(' %3.2f ', PcentIg(:,1)');
fprintf('\n%cInertie cum.: ','%'); fprintf(' %3.2f ', PcentIg(:,2)');
fprintf('\n\n');
%
% Histogramme de l'inertie
figure; hold on; 
bar(PcentIg(:,1)); 
plot(PcentIg(:,2),'-or','linewidth',1.5);
for i=1:Nvappos
    text(i-0.3,PcentIg(i,1)+2.0,sprintf('%.2f',PcentIg(i,1)),'fontweight','demi');
end
for i=2:Nvappos
    %text(i+0.2,PcentIg(i,2)+0.5,sprintf('%.2f',PcentIg(i,2)),'fontweight','demi');
    text(i+0.05,PcentIg(i,2)-2.0,sprintf('%.2f',PcentIg(i,2)),'fontweight','demi');
end
axis([0 Nvappos+1 0 100]); xlabel('composantes principales');
title(sprintf('Pourcentage d''inertie des %d(/%d) premires valeurs propres (>0)',length(Ipos),length(ValPropres)));
%
%----------------------------------------------------------------
